==> stepup_reprep-2.0.2.tar.gz: stepup_reprep-2.0.2/tests/examples/tile_pdf/main.sh <==
#!/usr/bin/env -S bash -x
# Exit on first error and cleanup.
set -e
trap 'kill $(pgrep -g $$ | grep -v $$) > /dev/null 2> /dev/null || :' EXIT
rm -rvf $(cat .gitignore)

# Run the example
export SOURCE_DATE_EPOCH="315532800"
export PUBLIC="public/"
stepup -w -n 1 plan.py & # > current_stdout.txt &

# Wait for the director and get its socket.
export STEPUP_DIRECTOR_SOCKET=$(
  python -c "import stepup.core.director; print(stepup.core.director.get_socket())"
)

# Get the graph after completion of the pending steps.
python3 - << EOD
from stepup.core.interact import *
wait()
graph("current_graph")
EOD

# Reproducibility test
mv figure.pdf figure1.pdf
python3 - << EOD
from stepup.core.interact import *
from stepup.reprep.make_inventory import write_inventory
watch_delete("figure.pdf")
run()
join()
write_inventory("reproducibility_inventory.txt", ["figure.pdf", "figure1.pdf"])
EOD

# Wait for background processes, if any.
wait

# Check files that are expected to be present and/or missing.
[[ -f plan.py ]] || exit 1
[[ -f triangle.svg ]] || exit 1
[[ -f square.svg ]] || exit 1
[[ -f pentagon.svg ]] || exit 1
[[ -f hexagon.svg ]] || exit 1
[[ -f vertical.svg ]] || exit 1
[[ -f horizontal.svg ]] || exit 1
[[ -f triangle.pdf ]] || exit 1
[[ -f square.pdf ]] || exit 1
[[ -f pentagon.pdf ]] || exit 1
[[ -f hexagon.pdf ]] || exit 1
[[ -f vertical.pdf ]] || exit 1
[[ -f horizontal.pdf ]] || exit 1
[[ -f figure.pdf ]] || exit 1
[[ -f figure1.pdf ]] || exit 1
[[ -f reproducibility_inventory.txt ]] || exit 1

==> stepup_reprep-2.3.6.tar.gz: stepup_reprep-2.3.6/tests/examples/tile_pdf/main.sh <==
#!/usr/bin/env -S bash -x
# Exit on first error and cleanup.
set -e
trap 'kill $(pgrep -g $$ | grep -v $$) > /dev/null 2> /dev/null || :' EXIT
rm -rvf $(cat .gitignore)

# Run the example
export SOURCE_DATE_EPOCH="315532800"
export PUBLIC="public/"
stepup -w -n 1 & # > current_stdout.txt &

# Wait for the director and get its socket.
export STEPUP_DIRECTOR_SOCKET=$(
  python -c "import stepup.core.director; print(stepup.core.director.get_socket())"
)

# Get the graph after completion of the pending steps.
python3 - << EOD
from stepup.core.interact import *
wait()
graph("current_graph")
EOD

# Reproducibility test
mv figure.pdf figure1.pdf
python3 - << EOD
from stepup.core.interact import *
from stepup.reprep.make_inventory import write_inventory
watch_delete("figure.pdf")
run()
join()
write_inventory("reproducibility_inventory.txt", ["figure.pdf", "figure1.pdf"])
EOD

# Wait for background processes, if any.
wait

# Check files that are expected to be present and/or missing.
[[ -f plan.py ]] || exit 1
[[ -f triangle.svg ]] || exit 1
[[ -f square.svg ]] || exit 1
[[ -f pentagon.svg ]] || exit 1
[[ -f hexagon.svg ]] || exit 1
[[ -f vertical.svg ]] || exit 1
[[ -f horizontal.svg ]] || exit 1
[[ -f triangle.pdf ]] || exit 1
[[ -f square.pdf ]] || exit 1
[[ -f pentagon.pdf ]] || exit 1
[[ -f hexagon.pdf ]] || exit 1
[[ -f vertical.pdf ]] || exit 1
[[ -f horizontal.pdf ]] || exit 1
[[ -f figure.pdf ]] || exit 1
[[ -f figure1.pdf ]] || exit 1
[[ -f reproducibility_inventory.txt ]] || exit 1
